@@ -31,9 +31,6 @@ def Get(name, release):
 		total = len(zip_ref.filelist)
 		for x, file in enumerate(zip_ref.filelist):
 			zip_ref.extract(member=file, path=f'Pragmatic/data/{name}')
-			try:
-				show_progress(x, 1, total)
-			except:
-				pass
+			show_progress(x, 1, total)
 
 	print('Done!')
\ No newline at end of file
